==> haskell-cabal-doctest-1.0.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.4
id: cabal-doctest-1.0.4-1fUOFSkY60TJdonvX3YG79
key: cabal-doctest-1.0.4-1fUOFSkY60TJdonvX3YG79
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: a6ef44fb8787d58db6ff0369b8746323
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-doctest-1.0.4
hs-libraries: HScabal-doctest-1.0.4-1fUOFSkY60TJdonvX3YG79
depends:
    base-4.10.1.0 Cabal-2.0.1.0 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.5
id: cabal-doctest-1.0.5-Gd52edaiwQKJylPP6eAfMU
key: cabal-doctest-1.0.5-Gd52edaiwQKJylPP6eAfMU
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: 44fae8407374500160b68215396dfe74
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-doctest-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-doctest-1.0.5
hs-libraries: HScabal-doctest-1.0.5-Gd52edaiwQKJylPP6eAfMU
depends:
    base-4.10.1.0 Cabal-2.0.1.0 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
